@@ -4,7 +4,6 @@ import os
 from pathlib import Path
 
 from patchwork.common.context_strategy.langugues import PythonLanguage
-from patchwork.logger import logger
 from patchwork.step import Step
 from patchwork.steps.ExtractCodeContexts.ExtractCodeContexts import ExtractCodeContexts
 
@@ -13,8 +12,7 @@ class ExtractCodeMethodForCommentContexts(Step):
     required_keys = {}
 
     def __init__(self, inputs: dict):
-        logger.info(f"Run started {self.__class__.__name__}")
-
+        super().__init__(inputs)
         if not all(key in inputs.keys() for key in self.required_keys):
             raise ValueError(f'Missing required data: "{self.required_keys}"')
 
@@ -22,7 +20,7 @@ class ExtractCodeMethodForCommentContexts(Step):
         # rethink this, should be one level up and true by default
         self.force_code_contexts = inputs.get("force_code_contexts", False)
         self.allow_overlap_contexts = inputs.get("allow_overlap_contexts", True)
-        self.max_depth = float(inputs.get("max_depth", float('inf')))
+        self.max_depth = int(inputs.get("max_depth", -1))
 
     def run(self) -> dict:
         positions_gen = ExtractCodeContexts(
@@ -32,7 +30,7 @@ class ExtractCodeMethodForCommentContexts(Step):
                 force_code_contexts=self.force_code_contexts,
                 allow_overlap_contexts=self.allow_overlap_contexts,
             )
-        ).get_positions(max_depth = self.max_depth)
+        ).get_positions(max_depth=self.max_depth)
 
         extracted_code_contexts = []
         for file_path, src, position in positions_gen:
@@ -40,12 +38,14 @@ class ExtractCodeMethodForCommentContexts(Step):
             if comment_position is not None:
                 start_line = comment_position.start
                 end_line = comment_position.end
+            elif isinstance(position.language, PythonLanguage) and position.meta_positions.get("body") is not None:
+                # if the comment is not found in python functions/methods, we will use the body position
+                body_position = position.meta_positions.get("body")
+                start_line = body_position.start
+                end_line = body_position.start
             else:
                 start_line = position.start
                 end_line = position.start
-                if isinstance(position.language, PythonLanguage):
-                    start_line = start_line + 1
-                    end_line = end_line + 1
 
             extracted_code_context = dict(
                 uri=file_path,
@@ -56,8 +56,6 @@ class ExtractCodeMethodForCommentContexts(Step):
             )
             extracted_code_contexts.append(extracted_code_context)
 
-        logger.info(f"Run completed {self.__class__.__name__}")
-
         return dict(
             files_to_patch=extracted_code_contexts,
         )
